"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AssetsCopyProcessor = void 0;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class AssetsCopyProcessor {
  constructor(config, filesystem = _fsExtra.default) {
    this.config = config;
    this.filesystem = filesystem;

    _defineProperty(this, "queue", []);
  }

  async copyAsset(from, to) {
    this.config.logger.debug('Copying asset:', from, 'to:', to);
    await this.filesystem.ensureDir(_path.default.dirname(to));
    await this.filesystem.copyFile(from, to);
  }

  enqueueChunk(chunk, {
    isEntry
  }) {
    var _compilation$assetsIn, _compilation$assetsIn2;

    const {
      compilation,
      outputPath,
      bundleOutput,
      sourcemapOutput,
      bundleOutputDir,
      assetsDest,
      platform
    } = this.config;

    const sourcemapOutputDir = _path.default.dirname(sourcemapOutput);

    const [chunkFile] = [...chunk.files];
    const relatedSourceMap = (_compilation$assetsIn = compilation.assetsInfo.get(chunkFile)) === null || _compilation$assetsIn === void 0 ? void 0 : (_compilation$assetsIn2 = _compilation$assetsIn.related) === null || _compilation$assetsIn2 === void 0 ? void 0 : _compilation$assetsIn2.sourceMap;
    const sourceMapFile = Array.isArray(relatedSourceMap) ? relatedSourceMap[0] : relatedSourceMap;
    this.queue.push(() => this.copyAsset(_path.default.join(outputPath, chunkFile), isEntry ? bundleOutput : _path.default.join(platform === 'ios' ? assetsDest : bundleOutputDir, chunkFile)));

    if (sourceMapFile) {
      this.queue.push(() => this.copyAsset(_path.default.join(outputPath, sourceMapFile), isEntry ? sourcemapOutput : _path.default.join(platform === 'ios' ? assetsDest : sourcemapOutputDir, sourceMapFile)));
    }

    const mediaAssets = [...chunk.auxiliaryFiles].filter(file => !/\.(map|bundle\.json)$/.test(file));
    this.queue.push(...mediaAssets.map(asset => () => this.copyAsset(_path.default.join(outputPath, asset), _path.default.join(assetsDest, asset))));
    const manifests = [...chunk.auxiliaryFiles].filter(file => /\.bundle\.json$/.test(file));
    this.queue.push(...manifests.map(asset => () => this.copyAsset(_path.default.join(outputPath, asset), _path.default.join(platform === 'ios' ? assetsDest : bundleOutputDir, asset))));
  }

  execute() {
    const queue = this.queue;
    this.queue = [];
    return queue.map(work => work());
  }

}

exports.AssetsCopyProcessor = AssetsCopyProcessor;
//# sourceMappingURL=AssetsCopyProcessor.js.map